Base class of runQuality/setQuality
Base class of runQuality/setQuality
metadataThe metadata for this run/setQuality
qualityMetricsArray of MzQCqualityMetric objects
new()Constructor
MzQCbaseQuality$new(metadata = MzQCmetadata$new(), qualityMetrics = list())metadataOptional MzQCmetadata value for initialization of field metadata
qualityMetricsOptional list value for initialization of field qualityMetrics
isValid()Verifies validity of the object
MzQCbaseQuality$isValid(context = "MzQCbaseQuality")contextOptional string describing location in mzQC structure that is used for more informative warning texts.
getMetric()Fetches metrics which match specified accession or name from the object.
MzQCbaseQuality$getMetric(accession = NULL, name = NULL)accessionSearch by accession
nameSearch by name
toJSON()Creates JSON file from this object.
MzQCbaseQuality$toJSON(...)...Optional parameters for jsonlite:::asJSON()
fromData()Sets data for this object from plain named lists of R objects
MzQCbaseQuality$fromData(mdata, context = "MzQCbaseQuality")mdataA datastructure of R lists/arrays as obtained by 'jsonlite::fromJSON()'
contextOptional string describing location in mzQC structure that is used for more informative warning texts.
clone()The objects of this class are cloneable with this method.
MzQCbaseQuality$clone(deep = FALSE)deepWhether to make a deep clone.