Learn R Programming

rmzqc (version 0.7.0)

MzQCbaseQuality_getMetric: Extract a certain metric from a runQuality's list of MzQCqualityMetric

Description

You must provide either the accession or the name of the metric, but not both.

Value

A list of MzQCqualityMetric's which match.

Arguments

accession

Accession of the MzQCqualityMetric

name

Name of the MzQCqualityMetric (less stable than accession)

Details

Usually there should be only one MzQCqualityMetric which matches, however, this function will return all matches.

Note: this function will stop() if not results are found