powered by
A controlled vocabulary document, usually pointing to an .obo file
name
Full name of the controlled vocabulary.
uri
Publicly accessible URI of the controlled vocabulary.
version
(optional) Version of the controlled vocabulary.
MzQCcontrolledVocabulary$new()
MzQCcontrolledVocabulary$isValid()
MzQCcontrolledVocabulary$toJSON()
MzQCcontrolledVocabulary$fromData()
MzQCcontrolledVocabulary$clone()
new()
Constructor
MzQCcontrolledVocabulary$new( name = NA_character_, uri = NA_character_, version = NA_character_ )
String value for initialization of field name
String value for initialization of field uri
Optional string value for initialization of field version
isValid()
Verifies validity of the object
MzQCcontrolledVocabulary$isValid(context = "MzQCcontrolledVocabulary")
context
Optional string describing location in mzQC structure that is used for more informative warning texts.
toJSON()
Creates JSON file from this object.
MzQCcontrolledVocabulary$toJSON(...)
...
Optional parameters for jsonlite:::asJSON()
fromData()
Sets data for this object from plain named lists of R objects
MzQCcontrolledVocabulary$fromData(data, context = "MzQCcontrolledVocabulary")
data
A datastructure of R lists/arrays as obtained by 'jsonlite::fromJSON()'
clone()
The objects of this class are cloneable with this method.
MzQCcontrolledVocabulary$clone(deep = FALSE)
deep
Whether to make a deep clone.
MzQCcontrolledVocabulary$new( "Proteomics Standards Initiative Quality Control Ontology", "https://github.com/HUPO-PSI/psi-ms-CV/releases/download/v4.1.129/psi-ms.obo", "4.1.129")
Run the code above in your browser using DataLab