You must provide either the accession or the name of the metric, but not both.
A list of MzQCqualityMetric's which match.
Accession of the MzQCqualityMetric
Name of the MzQCqualityMetric (less stable than accession)
Usually there should be only one MzQCqualityMetric which matches, however, this function will return all matches.
Note: this function will stop() if not results are found