powered by
A controlled vocabulary parameter, as detailed in the OBO file
accession
Accession number identifying the term within its controlled vocabulary.
name
Name of the controlled vocabulary term describing the parameter.
value
(optional) Value of the parameter.
description
(optional) Definition of the controlled vocabulary term.
MzQCcvParameter$new()
MzQCcvParameter$isValid()
MzQCcvParameter$toJSON()
MzQCcvParameter$fromData()
MzQCcvParameter$clone()
new()
Constructor
MzQCcvParameter$new( accession = NA_character_, name = NA_character_, value = NA, description = NA_character_ )
String value for initialization of field accession
String value for initialization of field name
Optional value for initialization of field value
Optional string value for initialization of field description
isValid()
Verifies validity of the object
MzQCcvParameter$isValid(context = "MzQCcvParameter")
context
Optional string describing location in mzQC structure that is used for more informative warning texts.
toJSON()
Creates JSON file from this object.
MzQCcvParameter$toJSON(...)
...
Optional parameters for jsonlite:::asJSON()
fromData()
Sets data for this object from plain named lists of R objects
MzQCcvParameter$fromData(data, context = "MzQCcvParameter")
data
A datastructure of R lists/arrays as obtained by 'jsonlite::fromJSON()'
clone()
The objects of this class are cloneable with this method.
MzQCcvParameter$clone(deep = FALSE)
deep
Whether to make a deep clone.
MzQCcvParameter$new("MS:4000070", "retention time acquisition range", c(0.2959, 5969.8172)) isValidMzQC(MzQCcvParameter$new("MS:0000000"))
Run the code above in your browser using DataLab